@@ -20,7 +20,7 @@ class Character:
     """
 
     def __init__(self, **kwargs):
-        """Intialize a new Character."""
+        """Initialize a new Character."""
         for k, v in kwargs.items():
             setattr(self, k, v)
 
