@@ -156,12 +156,15 @@ class IssueSchema(Schema):
     .. versionadded:: 2.2.2
 
         - Add ``collection_title`` field
+
+    .. versionchanged:: 2.3.0
+
+        - Removed ``volume`` field. The series object will have that information.
     """
 
     id = fields.Int()
     publisher = fields.Nested(publisher.PublisherSchema)
     series = fields.Nested(series.SeriesSchema)
-    volume = fields.Int()
     number = fields.Str()
     collection_title = fields.Str(allow_none=True, data_key="title")
     story_titles = fields.List(fields.Str(allow_none=True), data_key="name")
