@@ -23,7 +23,7 @@ class SqliteCache:
     def __init__(
         self, db_name: str = "mokkari_cache.db", expire: Optional[int] = None
     ) -> None:
-        """Intialize a new SqliteCache."""
+        """Initialize a new SqliteCache."""
         self.expire = expire
         self.con = sqlite3.connect(db_name)
         self.cur = self.con.cursor()
